@@ -3,7 +3,7 @@ const defaultOptions = {
   editTimeManually: false,
   color: 'primary',
   isRange: false,
-  lang: 'en', // internationalization
+  lang: 'en-US', // internationalization
   startTime: undefined,
   endTime: undefined,
   minTime: null,
@@ -11,4 +11,4 @@ const defaultOptions = {
   minuteSteps: 5
 };
 
-export default defaultOptions;
\ No newline at end of file
+export default defaultOptions;
